-- Es copia la taula monthly_fees de la Staging Area a la taula quotes del DW
INSERT clubfitnessdw.quotes
SELECT *
FROM cfstagingarea.monthly_fees;

-- S'actualitzen els camps String importats del CSV amb l'string correcte
UPDATE clubfitnessdw.quotes SET codi = 'CHILD' WHERE codi LIKE '%CHILD%';
UPDATE clubfitnessdw.quotes SET codi = 'TEEN' WHERE codi LIKE '%TEEN%';
UPDATE clubfitnessdw.quotes SET codi = 'ADUL' WHERE codi LIKE '%ADUL%';
UPDATE clubfitnessdw.quotes SET codi = 'PENS' WHERE codi LIKE '%PENS%';
UPDATE clubfitnessdw.quotes SET codi = 'TENIS' WHERE codi LIKE '%TENIS%';
UPDATE clubfitnessdw.quotes SET codi = 'PADEL' WHERE codi LIKE '%PADEL%';
UPDATE clubfitnessdw.quotes SET codi = 'PETRA' WHERE codi LIKE '%PETRA%';


-- ------------------------------------------------------------------------------

-- Es copia la taula clubs de la Staging Area a la taula clubs del DW
INSERT clubfitnessdw.clubs
SELECT *
FROM cfstagingarea.clubs;

-- -----------------------------------------------------------------------------


-- Es copien la taula members de la Staging Area a la taula membres del DW (sense els atributs DATE)
INSERT INTO clubfitnessdw.membres (Club_name, Member_number, Member_name, City, Country, Sex, Marital_status, Monthly_tennis_fee, Monthly_padel_fee, Monthly_personal_trainer_fee)
SELECT `members`.`Club_name`, `members`.`Member_number`, `members`.`Member_name`, `members`.`City`, `members`.`Country`, `members`.`Sex`,
 `members`.`Marital_status`, `members`.`Monthly_tennis_fee`, `members`.`Monthly_padel_fee`, `members`.`Monthly_personal_trainer_fee`
FROM cfstagingarea.members;

-- Es copien els atributs de format DATE amb la conversio de VARCHAR a DATE corresponent, i s'assignen els valors dels camps AGE i AGE_GROUP
UPDATE
    clubfitnessdw.membres INNER JOIN cfstagingarea.members
SET
    clubfitnessdw.membres.Registration_data = str_to_date(cfstagingarea.members.Registration_data, '%d/%m/%Y'),
    clubfitnessdw.membres.Birth_date = str_to_date(cfstagingarea.members.Birth_date, '%d/%m/%Y'),
    clubfitnessdw.membres.Age = DATEDIFF(CURDATE(),str_to_date(cfstagingarea.members.Birth_date, '%d/%m/%Y')) DIV 365
    
    WHERE  (clubfitnessdw.membres.Club_name = cfstagingarea.members.Club_name 
      AND clubfitnessdw.membres.Member_number = cfstagingarea.members.Member_number);
      
UPDATE     
	clubfitnessdw.membres
SET  clubfitnessdw.membres.Group_age = IF(Age <= 20, 'Fins a 20 anys', IF((Age > 20 && Age <=30), 'de 21 a 30 anys', 
	IF((Age > 30 && Age <=40), 'de 31 a 40 anys', IF((Age > 40 && Age <=50), 'de 41 a 50 anys',
    IF((Age > 50 && Age <=60), 'de 51 a 60 anys', IF(Age > 60 , 'Majors de 60 anys', NULL))))));
    
    
UPDATE
    clubfitnessdw.membres INNER JOIN cfstagingarea.members
SET
    clubfitnessdw.membres.Since_when_is_debtor = str_to_date(cfstagingarea.members.Since_when_is_debtor, '%d/%m/%Y')

    WHERE  (clubfitnessdw.membres.Club_name = cfstagingarea.members.Club_name 
      AND clubfitnessdw.membres.Member_number = cfstagingarea.members.Member_number
      AND cfstagingarea.members.Since_when_is_debtor != 'null');
  

-- Es crea una PK autoincrementable a la taula membres per tenir una PrimaryKey unica (no combinada) de cara al cub OLAP
ALTER TABLE clubfitnessdw.membres ADD MembreId INT UNSIGNED NOT NULL AUTO_INCREMENT FIRST,
  ADD PRIMARY KEY (MembreId);

-- ---------------------------------------------------------------------------------------------------------

-- Omplim la taula de Temps amb les dades temporals dels registres d'accessos de la Staging Area
INSERT INTO clubfitnessdw.temps (TempsId, TempsComplet)
    SELECT DISTINCT UNIX_TIMESTAMP(str_to_date(TempsAcces, '%d/%m/%Y %H:%i')), str_to_date(TempsAcces, '%d/%m/%Y %H:%i')
		FROM cfstagingarea.access;

-- S'acaben d'omplir tots els camps de la taula temps a partir de la data completa
UPDATE clubfitnessdw.temps
	SET Dia = DAY(TempsComplet), Mes = MONTH(TempsComplet), NomMes = MONTHNAME(TempsComplet), Trimestre = QUARTER(TempsComplet),
        NumAny = YEAR(TempsComplet), Hora = HOUR(TempsComplet), Minut = MINUTE(TempsComplet), DiaSetmana =DAYOFWEEK(TempsComplet), 
        DescripcioDiaSetmana = DAYNAME(TempsComplet);
			
-- ------------------------------------------------------------------------------------------------------------------------------

-- Es crea una PK autoincrementable a la taula accessos de la Staging Area
ALTER TABLE cfstagingarea.access ADD AccesId INT UNSIGNED NOT NULL AUTO_INCREMENT FIRST,
  ADD PRIMARY KEY (AccesId);
  
-- S'actualitzen els camps String importats del CSV amb l'string correcte
UPDATE cfstagingarea.access SET Club = 'ASTU' WHERE Club LIKE '%ASTU%';
UPDATE cfstagingarea.access SET Club = 'BILB' WHERE Club LIKE '%BILB%';
UPDATE cfstagingarea.access SET Club = 'SEVI' WHERE Club LIKE '%SEVI%';
UPDATE cfstagingarea.access SET Club = 'LVTE' WHERE Club LIKE '%LVTE%';
UPDATE cfstagingarea.access SET Club = 'KOLN' WHERE Club LIKE '%KOLN%';
UPDATE cfstagingarea.access SET Club = 'DENV' WHERE Club LIKE '%DENV%';
       
  
-- S'omple la taula Accessos del DW a partir de les dades de la Staging Area, i li vinculem el TempsId 
-- corresponent de la taula temps del DW
INSERT INTO clubfitnessdw.accessos (MemberId, ClubId, TempsId)
    SELECT (SELECT MembreId from membres where membres.Member_number = cfstagingarea.access.Member_number and membres.Club_name = cfstagingarea.access.Club), 
		Club, UNIX_TIMESTAMP(str_to_date(TempsAcces, '%d/%m/%Y %H:%i'))
			FROM cfstagingarea.access;


-- Crida del procediment que crea els registres mensuals de la taula de temps per analitzar 'ingressos' i 'accessos'
call clubfitnessdw.creacio_unitats_calendari();

-- Crida del procediment que omple la taula de fets ingressos amb els càlculs pertinents
call clubfitnessdw.omplir_ingressos();

